<?php
/**
 * Add Front Page -> Featured Slider settings.
 *
 * @package Bizness
 */

$fields = [
    'hero_group_settings' => [
        'type'              => 'group-field',
        'section'           => 'hero_section',
        'priority'          => 5,
        'tabs'              => [
            'desktop'            => [
                'nicename'      => esc_html__( '&gt; 1200px', 'bizness' ),
                'preview'       => 'desktop',
                'active_tab'    => true,
                'controls'      => [
                    'hero_home_page_enable',
                    'hero_single_pages_enable',
                    'hero_single_posts_enable',
                    'hero_title_sep',
                    'hero_title_text',
                    'hero_title_typography',
                    'hero_content_sep',
                    'hero_content_desc',
                    'hero_content_typography',
                    'hero_button_sep',
                    'hero_button_enable',
                    'hero_button_text',
                    'hero_button_url',
                    'hero_button_typography',
                    'hero_container_sep',
                    'hero_container_bg_image',
                    'hero_container_border_color',
                    'hero_container_padding'
                ]
            ],
            'tablet'            => [
                'nicename'      => esc_html__( '&gt; 768px', 'bizness' ),
                'preview'       => 'tablet',
                'active_tab'    => false,
                'controls'      => [
                    'hero_title_sep',
                    'hero_title_md_typography',
                    'hero_content_sep',
                    'hero_content_md_typography',
                    'hero_button_sep',
                    'hero_button_md_typography',
                    'hero_container_sep',
                    'hero_container_md_padding'
                ]
            ],
            'mobile'            => [
                'nicename'      => esc_html__( '&lt; 576px', 'bizness' ),
                'preview'       => 'mobile',
                'active_tab'    => false,
                'controls'      => [
                    'hero_title_sep',
                    'hero_title_sm_typography',
                    'hero_content_sep',
                    'hero_content_sm_typography',
                    'hero_button_sep',
                    'hero_button_sm_typography',
                    'hero_container_sep',
                    'hero_container_sm_padding'
                ]
            ]
        ],
    ],
    'hero_home_page_enable'  => [
        'type'              => 'toggle',
        'label'             => esc_html__( 'Home/Blog Page', 'bizness' ),
        'description'       => esc_html__( 'Toggle to enable hero on home page only.', 'bizness' ),
        'section'           => 'hero_section',
        'default'           => false,
        'priority'          => 10,
    ],
    'hero_single_pages_enable'  => [
        'type'              => 'toggle',
        'label'             => esc_html__( 'Single Pages', 'bizness' ),
        'description'       => esc_html__( 'Toggle to enable hero on all single pages.', 'bizness' ),
        'section'           => 'hero_section',
        'default'           => false,
        'priority'          => 10,
    ],
    'hero_single_posts_enable'  => [
        'type'              => 'toggle',
        'label'             => esc_html__( 'Single Posts', 'bizness' ),
        'description'       => esc_html__( 'Toggle to enable hero on all single posts.', 'bizness' ),
        'section'           => 'hero_section',
        'default'           => false,
        'priority'          => 10,        
    ],
    'hero_title_sep' => [
        'type'              => 'custom',
        'section'           => 'hero_section',
        'default'           => '<h3 style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0 -11px;padding: 8px 12px;background: #fff;">' . esc_html__( 'Heading', 'bizness' ) . '</h3>',
        'priority'          => 15
    ],
    'hero_title_text'  => [
        'type'              => 'text',
        'label'             => esc_html__( 'Text', 'bizness' ),
        'section'           => 'hero_section',
        'default'           => esc_html__( 'Enter Your Headline Here', 'bizness' ),
        'priority'          => 15
    ],
    'hero_title_typography' => [
        'type'              => 'typography',
        'section'           => 'hero_section',
        'priority'          => 15,
        'transport'         => 'auto',
        'default'           => [
            'font-family'       => '',
            'variant'           => '',
            'font-size'         => '',
            'font-style'        => '',
            'line-height'       => '',
            'letter-spacing'    => '',
            'color'             => '',
            'text-transform'    => 'none',
        ],
        'output'            => [
            [
                'element'       => '.hero-section .hero-text h2',
            ],
        ]
    ],
    'hero_title_md_typography'  => [
        'type'              => 'dimensions',
        'section'           => 'hero_section',
        'default'           => [
            'font-size'         => '',
            'line-height'       => '',
            'letter-spacing'    => '',
        ],
        'choices'           => [
            'labels'            => [
                'font-size'         => esc_html__( 'Font Size', 'bizness' ),
                'line-height'       => esc_html__( 'Line Height', 'bizness' ),
                'letter-spacing'    => esc_html__( 'Letter Spacing', 'bizness' ),
            ],
        ],
        'priority'          => 15,
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'font-size',
	            'property'      => 'font-size',
                'element'       => '.hero-section .hero-text h2',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'line-height',
	            'property'      => 'line-height',
                'element'       => '.hero-section .hero-text h2',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'letter-spacing',
	            'property'      => 'letter-spacing',
                'element'       => '.hero-section .hero-text h2',
            ],
        ],
    ],
    'hero_title_sm_typography'  => [
        'type'              => 'dimensions',
        'section'           => 'hero_section',
        'default'           => [
            'font-size'         => '',
            'line-height'       => '',
            'letter-spacing'    => '',
        ],
        'choices'           => [
            'labels'            => [
                'font-size'         => esc_html__( 'Font Size', 'bizness' ),
                'line-height'       => esc_html__( 'Line Height', 'bizness' ),
                'letter-spacing'    => esc_html__( 'Letter Spacing', 'bizness' ),
            ],
        ],
        'priority'          => 15,
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'font-size',
	            'property'      => 'font-size',
                'element'       => '.hero-section .hero-text h2',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'line-height',
	            'property'      => 'line-height',
                'element'       => '.hero-section .hero-text h2',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'letter-spacing',
	            'property'      => 'letter-spacing',
                'element'       => '.hero-section .hero-text h2',
            ],
        ],
    ],
    'hero_content_sep' => [
        'type'              => 'custom',
        'section'           => 'hero_section',
        'default'           => '<h3 style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0 -11px;padding: 8px 12px;background: #fff;">' . esc_html__( 'Content', 'bizness' ) . '</h3>',
        'priority'          => 20
    ],
    'hero_content_desc' => [
        'type'              => 'textarea',
        'default'           => esc_html__( 'Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor.', 'bizness' ),
        'section'           => 'hero_section',
        'priority'          => 20,
        'output'            => [
            [
                'element'       => '.hero-section .hero-text p',
            ],
        ]
    ],
    'hero_content_typography' => [
        'type'              => 'typography',
        'section'           => 'hero_section',
        'priority'          => 20,
        'transport'         => 'auto',
        'default'           => [
            'font-family'       => '',
            'variant'           => '',
            'font-size'         => '',
            'font-style'        => '',
            'line-height'       => '',
            'letter-spacing'    => '',
            'color'             => '',
            'text-transform'    => 'none',
        ],
        'output'            => [
            [
                'element'       => '.hero-section .hero-text p',
            ],
        ]
    ],
    'hero_content_md_typography'  => [
        'type'              => 'dimensions',
        'section'           => 'hero_section',
        'default'           => [
            'font-size'         => '',
            'line-height'       => '',
            'letter-spacing'    => '',
        ],
        'choices'           => [
            'labels'            => [
                'font-size'         => esc_html__( 'Font Size', 'bizness' ),
                'line-height'       => esc_html__( 'Line Height', 'bizness' ),
                'letter-spacing'    => esc_html__( 'Letter Spacing', 'bizness' ),
            ],
        ],
        'priority'          => 20,
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'font-size',
	            'property'      => 'font-size',
                'element'       => '.hero-section .hero-text p',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'line-height',
	            'property'      => 'line-height',
                'element'       => '.hero-section .hero-text p',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'letter-spacing',
	            'property'      => 'letter-spacing',
                'element'       => '.hero-section .hero-text p',
            ],
        ],
    ],
    'hero_content_sm_typography'  => [
        'type'              => 'dimensions',
        'section'           => 'hero_section',
        'default'           => [
            'font-size'         => '',
            'line-height'       => '',
            'letter-spacing'    => '',
        ],
        'choices'           => [
            'labels'            => [
                'font-size'         => esc_html__( 'Font Size', 'bizness' ),
                'line-height'       => esc_html__( 'Line Height', 'bizness' ),
                'letter-spacing'    => esc_html__( 'Letter Spacing', 'bizness' ),
            ],
        ],
        'priority'          => 20,
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'font-size',
	            'property'      => 'font-size',
                'element'       => '.hero-section .hero-text p',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'line-height',
	            'property'      => 'line-height',
                'element'       => '.hero-section .hero-text p',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'letter-spacing',
	            'property'      => 'letter-spacing',
                'element'       => '.hero-section .hero-text p',
            ],
        ],
    ],
    'hero_button_sep' => [
        'type'              => 'custom',
        'section'           => 'hero_section',
        'default'           => '<h3 style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0 -11px;padding: 8px 12px;background: #fff;">' . esc_html__( 'Button', 'bizness' ) . '</h3>',
        'priority'          => 22
    ],
    'hero_button_enable'  => [
        'type'              => 'toggle',
        'label'             => esc_html__( 'Enable', 'bizness' ),
        'description'       => esc_html__( 'Toggle to enable/disable button on hero content.', 'bizness' ),
        'section'           => 'hero_section',
        'default'           => false,
        'priority'          => 22,
    ],
    'hero_button_text'  => [
        'type'              => 'text',
        'label'             => esc_html__( 'Text', 'bizness' ),
        'section'           => 'hero_section',
        'default'           => esc_html__( 'Discover', 'bizness' ),
        'priority'          => 22
    ],
    'hero_button_url'  => [
        'type'              => 'url',
        'label'             => esc_html__( 'URL', 'bizness' ),
        'section'           => 'hero_section',
        'default'           => '#',
        'priority'          => 22
    ],
    'hero_button_typography' => [
        'type'              => 'typography',
        'section'           => 'hero_section',
        'priority'          => 22,
        'transport'         => 'auto',
        'default'           => [
            'font-family'       => '',
            'variant'           => '',
            'font-size'         => '',
            'font-style'        => '',
            'line-height'       => '',
            'letter-spacing'    => '',
            'color'             => '',
            'text-transform'    => 'none',
        ],
        'output'            => [
            [
                'element'       => '.hero-container button a.hero-button',
            ],
        ]
    ],
    'hero_button_md_typography'  => [
        'type'              => 'dimensions',
        'section'           => 'hero_section',
        'default'           => [
            'font-size'         => '',
            'line-height'       => '',
            'letter-spacing'    => '',
        ],
        'choices'           => [
            'labels'            => [
                'font-size'         => esc_html__( 'Font Size', 'bizness' ),
                'line-height'       => esc_html__( 'Line Height', 'bizness' ),
                'letter-spacing'    => esc_html__( 'Letter Spacing', 'bizness' ),
            ],
        ],
        'priority'          => 22,
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'font-size',
	            'property'      => 'font-size',
                'element'       => '.hero-container button a.hero-button',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'line-height',
	            'property'      => 'line-height',
                'element'       => '.hero-container button a.hero-button',
            ],
            [
                'media_query'   => '@media (max-width: 768px)',
                'choice'        => 'letter-spacing',
	            'property'      => 'letter-spacing',
                'element'       => '.hero-container button a.hero-button',
            ],
        ],
    ],
    'hero_button_sm_typography'  => [
        'type'              => 'dimensions',
        'section'           => 'hero_section',
        'default'           => [
            'font-size'         => '',
            'line-height'       => '',
            'letter-spacing'    => '',
        ],
        'choices'           => [
            'labels'            => [
                'font-size'         => esc_html__( 'Font Size', 'bizness' ),
                'line-height'       => esc_html__( 'Line Height', 'bizness' ),
                'letter-spacing'    => esc_html__( 'Letter Spacing', 'bizness' ),
            ],
        ],
        'priority'          => 22,
        'transport'         => 'auto',
        'output'            => [
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'font-size',
	            'property'      => 'font-size',
                'element'       => '.hero-container button a.hero-button',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'line-height',
	            'property'      => 'line-height',
                'element'       => '.hero-container button a.hero-button',
            ],
            [
                'media_query'   => '@media (max-width: 576px)',
                'choice'        => 'letter-spacing',
	            'property'      => 'letter-spacing',
                'element'       => '.hero-container button a.hero-button',
            ],
        ],
    ],

    'hero_container_sep' => [
        'type'              => 'custom',
        'section'           => 'hero_section',
        'default'           => '<h3 style="border-width:1px 0;border-style: solid;border-color: #fff;margin:0 -11px;padding: 8px 12px;background: #fff;">' . esc_html__( 'Container', 'bizness' ) . '</h3>',
        'priority'          => 25
    ],
    'hero_container_bg_image'  => [
        'type'              => 'image',
        'label'             => esc_html__( 'Background Image', 'bizness' ),
        'section'           => 'hero_section',
        'default'           => '',
        'priority'          => 25,
    ],
    'hero_container_border_color'  => [
        'type'              => 'color',
        'label'             => esc_html__( 'Border Color', 'bizness' ),
        'section'           => 'hero_section',
        'default'           => '#ffffff',
        'choices'           => [
            'alpha'         => true,
        ],
        'priority'          => 25,
        'transport'         => 'auto',
        'output'            => [
            [
                'element'   => '.hero-container .hero-border',
                'property'  => 'border-color',
            ],
            [
                'element'   => '.hero-container .border-bottom',
                'property'  => 'border-bottom-color',
                'suffix'    => '!important'
            ]
        ]
    ],
    'hero_container_padding' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Padding', 'bizness' ),
        'description' => esc_html__( 'Set container padding.', 'bizness' ),
        'section'     => 'hero_section',
        'priority'    => 25,
        'default'     => [
            'padding-top'   => '6em',
            'padding-bottom'=> '8em',
        ],
        'choices'     => [
            'labels'    => [
                'padding-top'       => esc_html__( 'Top', 'bizness' ),
                'padding-bottom'    => esc_html__( 'Bottom', 'bizness' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'choice'    => 'padding-top',
	            'property'  => 'padding-top',
                'element'   => '.hero-section .hero-container'
            ],
            [
                'choice'    => 'padding-bottom',
	            'property'  => 'padding-bottom',
                'element'   => '.hero-section .hero-container'
            ],
        ],
    ],
    'hero_container_md_padding' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Padding', 'bizness' ),
        'description' => esc_html__( 'Set container padding.', 'bizness' ),
        'section'     => 'hero_section',
        'priority'    => 25,
        'default'     => [
            'padding-top'   => '6em',
            'padding-bottom'=> '8em',
        ],
        'choices'     => [
            'labels'    => [
                'padding-top'       => esc_html__( 'Top', 'bizness' ),
                'padding-bottom'    => esc_html__( 'Bottom', 'bizness' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'choice'    => 'padding-top',
	            'property'  => 'padding-top',
                'media_query' => '@media (max-width: 768px)',
                'element'   => '.hero-section .hero-container'
            ],
            [
                'choice'    => 'padding-bottom',
	            'property'  => 'padding-bottom',
                'media_query' => '@media (max-width: 768px)',
                'element'   => '.hero-section .hero-container'
            ],
        ],
    ],
    'hero_container_sm_padding' => [
        'type'        => 'dimensions',
        'label'       => esc_html__( 'Padding', 'bizness' ),
        'description' => esc_html__( 'Set container padding.', 'bizness' ),
        'section'     => 'hero_section',
        'priority'    => 25,
        'default'     => [
            'padding-top'   => '6em',
            'padding-bottom'=> '8em',
        ],
        'choices'     => [
            'labels'    => [
                'padding-top'       => esc_html__( 'Top', 'bizness' ),
                'padding-bottom'    => esc_html__( 'Bottom', 'bizness' ),
            ],
        ],
        'transport'         => 'auto',
        'output'            => [
            [
                'choice'    => 'padding-top',
	            'property'  => 'padding-top',
                'media_query' => '@media (max-width: 576px)',
                'element'   => '.hero-section .hero-container'
            ],
            [
                'choice'    => 'padding-bottom',
	            'property'  => 'padding-bottom',
                'media_query' => '@media (max-width: 576px)',
                'element'   => '.hero-section .hero-container'
            ],
        ],
    ]
    
];
foreach ( $fields as $field_id => $field_args ) {
    // Settings
    $field_args['settings'] = str_replace( '-', '_', $field_id );

    Kirki::add_field( 'bizness', $field_args );
}